/*
 * File:   main.c
 * Author: Peter
 *
 * Copyright (C) Peter P. Domitrovich, Jr., Ph.D. 2008
 * Reformatted on October 12, 2014, 7:46 PM
 */

// A Solution to a Programming Puzzle from itasoftware.com, Peter P.
//   Domitrovich, Ph.D., 2008
//
// Word Numbers
// "If the integers from 1 to 999,999,999 are written as words, sorted
//   alphabetically, and concatenated, what is the 51 billionth letter?"
//
// To be precise: if the integers from 1 to 999,999,999 are expressed in words
//   (omitting spaces, 'and', and punctuation[1]), and sorted alphabetically so
//   that the first six integers are
//
//    * eight
//    * eighteen
//    * eighteenmillion
//    * eighteenmillioneight
//    * eighteenmillioneighteen
//    * eighteenmillioneighteenthousand
//
// and the last is
//
//    * twothousandtwohundredtwo
//
// then reading top to bottom, left to right, the 28th letter completes the
//   spelling of the integer "eighteenmillion".
//
//
//
// The 51 billionth letter also completes the spelling of an integer. Which one,
//   and what is the sum of all the integers to that point?
//
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

// -----------------------------------------------------------------------------

// Define some useful constants.
#define ZERO 0LU
#define ONE 1LU
#define TEN 10LU
#define HUN 100LU
#define THOU 1000LU
#define TENTHOU 10000LU
#define HUNTHOU 100000LU
#define MIL 1000000LU
#define TENMIL 10000000LU
#define HUNMIL 100000000LU
#define BIL 1000000000LU
#define MAX_CHAR 100          // Max # of characters in a word-number.

// -----------------------------------------------------------------------------

// fn prototypes

// gives the words for 0-99
char *zero_to_99(unsigned long);

// gives the words hundred, thousand, million.
char *fac(double);

// processes 1 inclusive - 100
int one_hun(double *, int, unsigned long, int, FILE *);

// processes 100 inclusive - 1000
int hun_thou(double *, int, unsigned long, int, FILE *);

// processes 1000 inclusive - 10000
int thou_tenthou(double *, int, unsigned long, int, FILE *);

// processes 10000 inclusive - 100000
int tenthou_hunthou(double *, int, unsigned long, int, FILE *);

// processes 100000 inclusive - 1000000
int hunthou_mil(double *, int, unsigned long, int, FILE *);

// processes 1000000 inclusive - 10000000
int mil_tenmil(double *, int, unsigned long, int, FILE *);

// processes 10000000 inclusive - 100000000
int tenmil_hunmil(double *, int, unsigned long, int, FILE *);

// processes 100000000 inclusive - 1000000000
int hunmil_bil(double *, int, unsigned long, int, FILE *);

// processes 0 - 1000000000
void number_word(unsigned long, double *, int *, int, FILE *, int);

// converts words to numbers
double word_number(char *);

// var
char p[MAX_CHAR];
char str[MAX_CHAR];

// -----------------------------------------------------------------------------

int
main(int argv, char **argc) {

    char name[7][20], dumb[20];
    char com[100], dummy[MAX_CHAR], number[20];

    int i = 0, get = 0, numm[7], interval = 0, k = 0;
    int nn = 0, m = 0, no = 0, n = 0, inumber = 0;

    // j is used for the for loop from 0 to a BIL.
    unsigned long j = 0LU, jo = 0LU;

    // Note that the names of all word integers begin with
    //   one of the six following letters: e, f, n, o, s, t.
    //   The 999,999,999 word-integers are dealt with by
    //   separating them according to their first letter.
    //   This reduces the size of the file that needs to be
    //   sorted. Clearly, files alphabetically before or after
    //   the file of interest, which will be determined, do
    //   not need to be sorted at all.
    //
    // count is used to count the total number of characters
    //   used for each word beginning with e, f, n, o, s, or t.
    //   sum holds the sum of the actual integers
    double counts = 0.0, sums = 0.0, count[7], sum[7];
    double count_range_lower[7], count_range_upper[7];
    double sum_range_lower[7], sum_range_upper[7];
    double sum_to_number = 0.0, count_to_number = 0.0;
    double sum_to_numbero = 0.0, count_to_numbero = 0.0;
    double tmp = 0.0, diff = 0.0;
    double max_char = 0.0, min_int = 0.0, max_int = 0.0;

    FILE *foutp = NULL, *fout = NULL, *fanswer = NULL;

    // -------------------------------------------------------------------------

    if (argv != 3) {
        printf("Usage: ./wordnumbers number_of_characters_to_answer max_loop_integer ,\n");
        printf("where max_loop_int must be <= 1,000,000,000.\n");
        exit(1);
    }

    // -------------------------------------------------------------------------

    // check of command-line arguments

    if ((strlen(argc[2]) > 10) || ((strlen(argc[2]) == 10) && (argc[2][0] != '1'))) {
        printf("max_loop_int is too large. Exiting...\n");
        exit(1);
    }

    min_int = 1.0;
    max_int = atof(argc[2]) - 1.0;
    max_char = atof(argc[1]);
    printf("max_char= %.0lf ; min_int= %0.lf ; max_int= %.0lf .\n", max_char, min_int, max_int);

    // -------------------------------------------------------------------------

    // initialize vectors containing the number of characters and integer sums

    for (i = 0; i < 7; i++) {
        count[i] = 0.0;
        sum[i] = 0.0;
        count_range_lower[i] = 0.0;
        count_range_upper[i] = 0.0;
        sum_range_lower[i] = 0.0;
        sum_range_upper[i] = 0.0;
    }

    // -------------------------------------------------------------------------

    // remove old files

    if ((fout = fopen("out", "r")) != NULL) {
        fclose(fout);
        if (remove("out") != 0) {
            printf("Error removing out. Exiting... \n");
            exit(1);
        }
    }
    if ((fout = fopen("outp", "r")) != NULL) {
        fclose(fout);
        if (remove("outp") != 0) {
            printf("Error removing outp. Exiting... \n");
            exit(1);
        }
    }
    if ((fout = fopen("outsb", "rb")) != NULL) {
        fclose(fout);
        if (remove("outsb") != 0) {
            printf("Error removing outsb. Exiting... \n");
            exit(1);
        }
    }
    if ((fout = fopen("outs", "r")) != NULL) {
        fclose(fout);
        if (remove("outs") != 0) {
            printf("Error removing outs. Exiting... \n");
            exit(1);
        }
    }

    // -------------------------------------------------------------------------

    // Consider separately the cases: 0; 1-9; 10-99; 100-999; 1000-9999;
    //   10,000 - 99,999; 100,000 - 999,999; 1,000,000 - 9,999,999;
    //   10,000,000 - 99,999,999; 100,000,000 - 999,999,999;
    //   0 is skipped and 1BIL is the end of the for loop.
    //   The first loop finds the total number of characters for the
    //   6 sets of integer-words beginning with a unique letter: i.e.
    //   e,f,n,o,s, or t. This loop also sums all of the integers
    //   for each of the six sets of integer-words.
    //   Nothing is printed within this loop (see below: pr = 0);
    //   count is filled in the functions, while sum is filled directly
    //   int the following for loop. All 6 first letters are interesting,
    //   so getthisone = -1.


    // out contains the info to determine the correct file of word-integers
    //   to sort, the counts of characters, and the sums of the integers
    //   for each of the six groups of word-integers with first-letter
    //   prefixes, (e,f,n,o,s,t), leading the max_integer number of
    //   word_integers.

    fout = fopen("out", "w");
    if (fout == NULL) {
        printf("Cannot open out with fout. Exiting... \n");
        exit(1);
    }
    // Get the number of characters and sums for each of the 7 cases
    //   The fourth argument of number_word is 0, so no printing will be done.
    //   The last argument of word_numbers is -1, which means that all
    //   of the seven cases will be analyzed.

    for (j = ONE; j <= (unsigned long) (max_int); j += 1LU) {
        number_word(j, count, &get, 0, foutp, -1);
        if (get != -1)
            sum[get] += (double) j;
    }

    // -------------------------------------------------------------------------

    // Print to the file out the number of characters and sum for each case.

    fprintf(fout, "%c 1 %lf %lf\n", 'e', count[1], sum[1]);
    fprintf(fout, "%c 2 %lf %lf\n", 'f', count[2], sum[2]);
    fprintf(fout, "%c 3 %lf %lf\n", 'n', count[3], sum[3]);
    fprintf(fout, "%c 4 %lf %lf\n", 'o', count[4], sum[4]);
    fprintf(fout, "%c 5 %lf %lf\n", 's', count[5], sum[5]);
    fprintf(fout, "%c 6 %lf %lf\n", 't', count[6], sum[6]);

    if (fclose(fout) == EOF)
        exit(1);
    fout = NULL;

    // -------------------------------------------------------------------------

    // Determine which letter contains the inter-word that ends
    //   at the max_char character of the sum of all previous
    //   word-integers.

    fout = fopen("out", "r");
    if (fout == NULL)
        exit(1);

    for (i = 0; i < 7; i++) {
        count_range_lower[i] = 0.0;
        count_range_upper[i] = 0.0;
        sum_range_lower[i] = 0.0;
        sum_range_upper[i] = 0.0;
        numm[i] = 0;
    }

    i = 1;
    while (fscanf(fout, "%s %d %lf %lf\n", dumb, &k, &counts, &sums) == 4) {
        if (i > 1) {
            count_range_lower[i] = count_range_upper[i - 1];
            sum_range_lower[i] = sum_range_upper[i - 1];
        }

        if (i == 1) {
            count_range_upper[i] = counts;
            sum_range_upper[i] = sums;
        } else {
            count_range_upper[i] = counts + count_range_upper[i - 1];
            sum_range_upper[i] = sums + sum_range_upper[i - 1];
        }

        strcpy(name[i], dumb);
        numm[i] = k;
        i++;
    }
    n = i;

    if (fclose(fout) == EOF)
        exit(1);
    fout = NULL;

    // -------------------------------------------------------------------------

    // Find the interval which contains the value of max_char and save its
    //   id number, name, and the count and integer sum totals of all of the
    //   cases before the case which contains max_char.

    i = 1;
    while (i < n) {
        if ((count_range_lower[i] < max_char) &&
                ((count_range_upper[i] - max_char) > 1.0e-15)) {
            interval = i;
        }
        i++;
    }

    strcpy(number, name[interval]);
    inumber = numm[interval];
    sum_to_number = sum_range_lower[interval];
    count_to_number = count_range_lower[interval];
    printf("First letter of all word-integers in the file containing max_char = %.0lf is %s .\n",
            max_char, number);

    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------
    //                       second loop through the billion
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------

    // Begin the second loop. The integer is followed by the number
    //   and a space between both. This file will be sorted with the numerical
    //   value tagging along. This file contains all integer-words that begin
    //   with the letter that contains the answer desired. There is no
    //   need to use the previous sets of integer-words that alphabetically
    //   precede the set of the desired integer-word. One only needs the
    //   total number of characters (count_to_number) and total sum
    //   (sum_to_number). number is the letter that identifies the
    //   integer-word desired, and inumber is the integer value of the letter.
    //   Here gethisone = inumber in the fn word_numbers.

    for (i = 0; i < 7; i++) {
        count[i] = 0.0;
        sum[i] = 0.0;
    }

    foutp = fopen("outp", "w");
    if (foutp == NULL) {
        printf("Cannot open outp with foutp. Exiting... \n");
        exit(1);
    }

    for (j = ONE; j <= (unsigned long) (max_int); j += 1LU) {
        number_word(j, count, &get, 1, foutp, inumber);
    }

    if (fclose(foutp) == EOF)
        exit(1);
    foutp = NULL;

    // -------------------------------------------------------------------------

    //Sort the file outp using a system sort routine. The sorted file is outs.

    sprintf(com, "sort outp > outs\n");
    if (system(com) == -1)
        exit(1);

    // -------------------------------------------------------------------------

    // There is no need to concatenate all of the word-integers. One may simply
    //   find the integer before and after max_char, cut out enough of the
    //   word-integer that ends beyond max_char, and finally find its value,
    //   length, and name. The total count to max_char is found from
    //   count_to_number and the use of strlen for all of the sorted
    //   word-integers preceeding the word-integer beyond max_char. The integral
    //   value of all of the word-integers preceeding the word-integer whose end
    //   is beyond max_char is carried along in the sort, and these integral
    //   values are added to sum_to_number to get the final sum before the
    //   desired word at max_char. atof is used after one finds the name
    //   of the answer to obtain the integral value of the answer and add it to
    //   sum_to_number. count_to_number is computed and should equal max_char.

    fanswer = fopen("answer", "w");
    if (fanswer == NULL) {
        printf("Cannot open answer with fanswer. Exiting... \n");
        exit(1);
    }

    fout = fopen("outs", "r");
    if (fout == NULL) {
        printf("Cannot open out with fout. Exiting... \n");
        exit(1);
    }

    // find the answer

    j = 0UL;
    while (fscanf(fout, "%s\n", dummy) == 1) {
        memset(p, '\0', MAX_CHAR);
        strcpy(p, dummy);
        tmp = word_number(p);
        if (tmp < 0.0) {
            printf("Error in word_number while translating from outs. Exiting... \n");
            exit(1);
        }
        sum_to_number += tmp;
        nn = strlen(p);
        count_to_number += (double) nn;
        j++;
        if ((count_to_number - max_char) >= 0.0) {
            n = strlen(p);
            break;
        }
        count_to_numbero = count_to_number;
        sum_to_numbero = sum_to_number;
        jo = j;
        no = n;
    }
    if (fclose(fout) == EOF)
        exit(1);
    fout = NULL;

    // numbers of characters in the answer
    diff = max_char - count_to_numbero;
    m = 0;
    while (diff > 0.0) {
        count_to_numbero += 1.0;
        fprintf(fanswer, "%c", p[m]);
        m++;
        diff -= 1.0;
    }
    fprintf(fanswer, " %.0lf\n", count_to_numbero);
    if (fclose(fanswer) == EOF)
        exit(1);
    fanswer = NULL;

    fanswer = fopen("answer", "r");
    if (fanswer == NULL) {
        printf("Cannot open answer with fanswer. Exiting... \n");
        exit(1);
    }
    fscanf(fanswer, "%s %lf\n", dummy, &count_to_numbero);
    memset(p, '\0', MAX_CHAR);
    strcpy(p, dummy);

    tmp = word_number(p);
    if (tmp < 0.0) {
        printf("The answer is not a word!! \n");
    }
    sum_to_numbero += tmp;

    if (fclose(fanswer) == EOF)
        exit(1);
    fanswer = NULL;

    fanswer = fopen("finalanswer", "w");
    if (fanswer == NULL) {
        printf("Cannot open answer with fanswer. Exiting... \n");
        exit(1);
    }
    fprintf(fanswer, "%s %.0lf %.0lf\n", p, count_to_numbero, sum_to_numbero);
    if (fclose(fanswer) == EOF)
        exit(1);
    fanswer = NULL;

    // -------------------------------------------------------------------------

    return 0;

}

// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
// ----------------------------End-of-main--------------------------------------
// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------

// The first elements of fac and zero_to_99
//   should have a zero character length, and are therefore set to
//   the NULL character.
// -----------------------------------------------------------------------------

char *
fac(double j) {
    int jj = (int) (j);
    str[0] = '\0';
    if (jj == 0)
        return str;
    else if (jj == 1) {
        strcpy(str, "ten");
        return str;
    } else if (jj == 2) {
        strcpy(str, "hundred");
        return str;
    } else if (jj == 3) {
        strcpy(str, "thousand");
        return str;
    } else if (jj == 4) {
        strcpy(str, "million");
        return str;
    } else if (jj == 5) {
        strcpy(str, "billion");
        return str;
    } else
        return str;
    return str;
}

// -----------------------------------------------------------------------------

char *
zero_to_99(unsigned long j) {
    str[0] = '\0';
    if (j == 0LU)
        return str;
    else if (j == 1LU) {
        strcpy(str, "one");
        return str;
    } else if (j == 2LU) {
        strcpy(str, "two");
        return str;
    } else if (j == 3LU) {
        strcpy(str, "three");
        return str;
    } else if (j == 4LU) {
        strcpy(str, "four");
        return str;
    } else if (j == 5LU) {
        strcpy(str, "five");
        return str;
    } else if (j == 6LU) {
        strcpy(str, "six");
        return str;
    } else if (j == 7LU) {
        strcpy(str, "seven");
        return str;
    } else if (j == 8LU) {
        strcpy(str, "eight");
        return str;
    } else if (j == 9LU) {
        strcpy(str, "nine");
        return str;
    } else if (j == 10LU) {
        strcpy(str, "ten");
        return str;
    } else if (j == 11LU) {
        strcpy(str, "eleven");
        return str;
    } else if (j == 12LU) {
        strcpy(str, "twelve");
        return str;
    } else if (j == 13LU) {
        strcpy(str, "thirteen");
        return str;
    } else if (j == 14LU) {
        strcpy(str, "fourteen");
        return str;
    } else if (j == 15LU) {
        strcpy(str, "fifteen");
        return str;
    } else if (j == 16LU) {
        strcpy(str, "sixteen");
        return str;
    } else if (j == 17LU) {
        strcpy(str, "seventeen");
        return str;
    } else if (j == 18LU) {
        strcpy(str, "eighteen");
        return str;
    } else if (j == 19LU) {
        strcpy(str, "nineteen");
        return str;
    } else if (j == 20LU) {
        strcpy(str, "twenty");
        return str;
    } else if (j == 21LU) {
        strcpy(str, "twentyone");
        return str;
    } else if (j == 22LU) {
        strcpy(str, "twentytwo");
        return str;
    } else if (j == 23LU) {
        strcpy(str, "twentythree");
        return str;
    } else if (j == 24LU) {
        strcpy(str, "twentyfour");
        return str;
    } else if (j == 25LU) {
        strcpy(str, "twentyfive");
        return str;
    } else if (j == 26LU) {
        strcpy(str, "twentysix");
        return str;
    } else if (j == 27LU) {
        strcpy(str, "twentyseven");
        return str;
    } else if (j == 28LU) {
        strcpy(str, "twentyeight");
        return str;
    } else if (j == 29LU) {
        strcpy(str, "twentynine");
        return str;
    } else if (j == 30LU) {
        strcpy(str, "thirty");
        return str;
    } else if (j == 31LU) {
        strcpy(str, "thirtyone");
        return str;
    } else if (j == 32LU) {
        strcpy(str, "thirtytwo");
        return str;
    } else if (j == 33LU) {
        strcpy(str, "thirtythree");
        return str;
    } else if (j == 34LU) {
        strcpy(str, "thirtyfour");
        return str;
    } else if (j == 35LU) {
        strcpy(str, "thirtyfive");
        return str;
    } else if (j == 36LU) {
        strcpy(str, "thirtysix");
        return str;
    } else if (j == 37LU) {
        strcpy(str, "thirtyseven");
        return str;
    } else if (j == 38LU) {
        strcpy(str, "thirtyeight");
        return str;
    } else if (j == 39LU) {
        strcpy(str, "thirtynine");
        return str;
    } else if (j == 40LU) {
        strcpy(str, "forty");
        return str;
    } else if (j == 41LU) {
        strcpy(str, "fortyone");
        return str;
    } else if (j == 42LU) {
        strcpy(str, "fortytwo");
        return str;
    } else if (j == 43LU) {
        strcpy(str, "fortythree");
        return str;
    } else if (j == 44LU) {
        strcpy(str, "fortyfour");
        return str;
    } else if (j == 45LU) {
        strcpy(str, "fortyfive");
        return str;
    } else if (j == 46LU) {
        strcpy(str, "fortysix");
        return str;
    } else if (j == 47LU) {
        strcpy(str, "fortyseven");
        return str;
    } else if (j == 48LU) {
        strcpy(str, "fortyeight");
        return str;
    } else if (j == 49LU) {
        strcpy(str, "fortynine");
        return str;
    } else if (j == 50LU) {
        strcpy(str, "fifty");
        return str;
    } else if (j == 51LU) {
        strcpy(str, "fiftyone");
        return str;
    } else if (j == 52LU) {
        strcpy(str, "fiftytwo");
        return str;
    } else if (j == 53LU) {
        strcpy(str, "fiftythree");
        return str;
    } else if (j == 54LU) {
        strcpy(str, "fiftyfour");
        return str;
    } else if (j == 55LU) {
        strcpy(str, "fiftyfive");
        return str;
    } else if (j == 56LU) {
        strcpy(str, "fiftysix");
        return str;
    } else if (j == 57LU) {
        strcpy(str, "fiftyseven");
        return str;
    } else if (j == 58LU) {
        strcpy(str, "fiftyeight");
        return str;
    } else if (j == 59LU) {
        strcpy(str, "fiftynine");
        return str;
    } else if (j == 60LU) {
        strcpy(str, "sixty");
        return str;
    } else if (j == 61LU) {
        strcpy(str, "sixtyone");
        return str;
    } else if (j == 62LU) {
        strcpy(str, "sixtytwo");
        return str;
    } else if (j == 63LU) {
        strcpy(str, "sixtythree");
        return str;
    } else if (j == 64LU) {
        strcpy(str, "sixtyfour");
        return str;
    } else if (j == 65LU) {
        strcpy(str, "sixtyfive");
        return str;
    } else if (j == 66LU) {
        strcpy(str, "sixtysix");
        return str;
    } else if (j == 67LU) {
        strcpy(str, "sixtyseven");
        return str;
    } else if (j == 68LU) {
        strcpy(str, "sixtyeight");
        return str;
    } else if (j == 69LU) {
        strcpy(str, "sixtynine");
        return str;
    } else if (j == 70LU) {
        strcpy(str, "seventy");
        return str;
    } else if (j == 71LU) {
        strcpy(str, "seventyone");
        return str;
    } else if (j == 72LU) {
        strcpy(str, "seventytwo");
        return str;
    } else if (j == 73LU) {
        strcpy(str, "seventythree");
        return str;
    } else if (j == 74LU) {
        strcpy(str, "seventyfour");
        return str;
    } else if (j == 75LU) {
        strcpy(str, "seventyfive");
        return str;
    } else if (j == 76LU) {
        strcpy(str, "seventysix");
        return str;
    } else if (j == 77LU) {
        strcpy(str, "seventyseven");
        return str;
    } else if (j == 78LU) {
        strcpy(str, "seventyeight");
        return str;
    } else if (j == 79LU) {
        strcpy(str, "seventynine");
        return str;
    } else if (j == 80LU) {
        strcpy(str, "eighty");
        return str;
    } else if (j == 81LU) {
        strcpy(str, "eightyone");
        return str;
    } else if (j == 82LU) {
        strcpy(str, "eightytwo");
        return str;
    } else if (j == 83LU) {
        strcpy(str, "eightythree");
        return str;
    } else if (j == 84LU) {
        strcpy(str, "eightyfour");
        return str;
    } else if (j == 85LU) {
        strcpy(str, "eightyfive");
        return str;
    } else if (j == 86LU) {
        strcpy(str, "eightysix");
        return str;
    } else if (j == 87LU) {
        strcpy(str, "eightyseven");
        return str;
    } else if (j == 88LU) {
        strcpy(str, "eightyeight");
        return str;
    } else if (j == 89LU) {
        strcpy(str, "eightynine");
        return str;
    } else if (j == 90LU) {
        strcpy(str, "ninety");
        return str;
    } else if (j == 91LU) {
        strcpy(str, "ninetyone");
        return str;
    } else if (j == 92LU) {
        strcpy(str, "ninetytwo");
        return str;
    } else if (j == 93LU) {
        strcpy(str, "ninetythree");
        return str;
    } else if (j == 94LU) {
        strcpy(str, "ninetyfour");
        return str;
    } else if (j == 95LU) {
        strcpy(str, "ninetyfive");
        return str;
    } else if (j == 96LU) {
        strcpy(str, "ninetysix");
        return str;
    } else if (j == 97LU) {
        strcpy(str, "ninetyseven");
        return str;
    } else if (j == 98LU) {
        strcpy(str, "ninetyeight");
        return str;
    } else if (j == 99LU) {
        strcpy(str, "ninetynine");
        return str;
    } else
        return str;
    return str;
}

// -----------------------------------------------------------------------------

// These functions, which belong to the number_word function, map any integer
//   from 1-999,999,999 to an integer-word, count the length of the integer
//   word, and print the integer-word if desired.

// -----------------------------------------------------------------------------

// 1 - 100

int
one_hun(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    n = strlen(zero_to_99(j));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s\n", zero_to_99(j));
    return 0;
}

// -----------------------------------------------------------------------------

// 100 - 1000

int
hun_thou(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / HUN));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / HUN));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j))));
    jj -= HUN * (jj / HUN);
    if ((jj >= 1LU) && (jj < HUN)) {
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "\n");
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 1000 - 10000

int
thou_tenthou(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / THOU));
    count[get] += (double) n;
    //gives the thousand
    n = strlen(fac(log10(1.0 * (j))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / THOU));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j))));
    jj -= THOU * (jj / THOU);
    if ((jj >= HUN) && (jj < THOU)) {
        hun_thou(count, get, jj, pr, foutp);
    } else if ((jj >= 1LU) && (jj < HUN)) {
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "\n");
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 10000 - 100000

int
tenthou_hunthou(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / THOU));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j / TEN))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / THOU));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j / TEN))));
    jj -= THOU * (jj / THOU);
    if ((jj >= THOU) && (j < TENTHOU)) {
        thou_tenthou(count, get, jj, pr, foutp);
    } else if ((jj >= HUN) && (jj < THOU)) {
        hun_thou(count, get, jj, pr, foutp);
    } else if ((jj >= 1LU) && (jj < HUN)) {
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "\n");
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 100000 - 1000000

int
hunthou_mil(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / HUNTHOU));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j / THOU))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / HUNTHOU));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j / THOU))));
    jj -= HUNTHOU * (j / HUNTHOU);
    if ((jj >= TENTHOU) && (jj < HUNTHOU)) {
        tenthou_hunthou(count, get, jj, pr, foutp);
    } else if ((jj >= THOU) && (jj < TENTHOU)) {
        thou_tenthou(count, get, jj, pr, foutp);
    } else if ((jj >= HUN) && (jj < THOU)) {
        //supplies the thousand in these cases.
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / HUN))));
        n = strlen(fac(log10(1.0 * (j / HUN))));
        count[get] += (double) n;
        hun_thou(count, get, jj, pr, foutp);
    } else if ((jj >= 1LU) && (jj < HUN)) {
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / HUN))));
        n = strlen(fac(log10(1.0 * (j / HUN))));
        count[get] += (double) n;
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "%s\n", fac(log10(1.0 * (j / HUN))));
        n = strlen(fac(log10(1.0 * (j / HUN))));
        count[get] += (double) n;
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 1000000 - 10000000

int
mil_tenmil(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / MIL));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j / HUN))));
    count[get] += n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / MIL));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j / HUN))));
    jj -= MIL * (jj / MIL);
    if ((jj >= HUNTHOU) && (jj < MIL)) {
        hunthou_mil(count, get, jj, pr, foutp);
    } else if ((jj >= TENTHOU) && (jj < HUNTHOU)) {
        tenthou_hunthou(count, get, jj, pr, foutp);
    } else if ((jj >= THOU) && (jj < TENTHOU)) {
        thou_tenthou(count, get, jj, pr, foutp);
    } else if ((jj >= HUN) && (jj < THOU)) {
        hun_thou(count, get, jj, pr, foutp);
    } else if ((j >= 1LU) && (jj < HUN)) {
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "\n");
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 10000000 - 100000000

int
tenmil_hunmil(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / MIL));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j / THOU))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / MIL));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j / THOU))));
    jj -= MIL * (jj / MIL);
    if ((jj >= HUNTHOU) && (jj < MIL)) {
        hunthou_mil(count, get, jj, pr, foutp);
    } else if ((jj >= TENTHOU) && (jj < HUNTHOU)) {
        tenthou_hunthou(count, get, jj, pr, foutp);
    } else if ((jj >= THOU) && (jj < TENTHOU)) {
        thou_tenthou(count, get, jj, pr, foutp);
    } else if ((jj >= HUN) && (jj < THOU)) {
        hun_thou(count, get, jj, pr, foutp);
    } else if ((j >= 1LU) && (jj < HUN)) {
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "\n");
    }
    return 0;
}

// -----------------------------------------------------------------------------

// 100000000 - 1000000000

int
hunmil_bil(double count[], int get, unsigned long j, int pr, FILE * foutp) {
    int n = 0;
    unsigned long jj = 0LU;
    jj = j;
    n = strlen(zero_to_99(j / HUNMIL));
    count[get] += (double) n;
    n = strlen(fac(log10(1.0 * (j / MIL))));
    count[get] += (double) n;
    if (pr == 1)
        fprintf(foutp, "%s", zero_to_99(j / HUNMIL));
    if (pr == 1)
        fprintf(foutp, "%s", fac(log10(1.0 * (j / MIL))));
    jj -= HUNMIL * (jj / HUNMIL);
    if ((jj >= TENMIL) && (jj < HUNMIL)) {
        tenmil_hunmil(count, get, jj, pr, foutp);
    } else if ((jj >= MIL) && (jj < TENMIL)) {
        mil_tenmil(count, get, jj, pr, foutp);
    } else if ((jj >= HUNTHOU) && (jj < MIL)) {
        //supplies the million in these cases.
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
        hunthou_mil(count, get, jj, pr, foutp);
    } else if ((jj >= TENTHOU) && (jj < HUNTHOU)) {
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
        tenthou_hunthou(count, get, jj, pr, foutp);
    } else if ((jj >= THOU) && (jj < TENTHOU)) {
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
        thou_tenthou(count, get, jj, pr, foutp);
    } else if ((jj >= HUN) && (jj < THOU)) {
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
        hun_thou(count, get, jj, pr, foutp);
    } else if ((j >= 1LU) && (jj < HUN)) {
        if (pr == 1)
            fprintf(foutp, "%s", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
        one_hun(count, get, jj, pr, foutp);
    } else {
        if (pr == 1)
            fprintf(foutp, "%s\n", fac(log10(1.0 * (j / TENTHOU))));
        n = strlen(fac(log10(1.0 * (j / TENTHOU))));
        count[get] += (double) n;
    }
    return 0;
}

// -----------------------------------------------------------------------------

void
number_word(unsigned long j, double count[], int *getit, int pr, FILE * foutp,
        int getthisone) {
    char tmp[200];
    int get = -1;

    if (j / ONE == ZERO) {
        *getit = -1;
        return;
    }// ----------------------------------------------------------------

    else if (j / HUN == ZERO) {
        strcpy(tmp, zero_to_99(j));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        one_hun(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / THOU == ZERO) {
        strcpy(tmp, zero_to_99(j / HUN));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        hun_thou(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / TENTHOU == ZERO) {
        strcpy(tmp, zero_to_99(j / THOU));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        thou_tenthou(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / HUNTHOU == ZERO) {
        strcpy(tmp, zero_to_99(j / THOU));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        tenthou_hunthou(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / MIL == ZERO) {
        strcpy(tmp, zero_to_99(j / HUNTHOU));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        hunthou_mil(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / TENMIL == ZERO) {
        strcpy(tmp, zero_to_99(j / MIL));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        mil_tenmil(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / HUNMIL == ZERO) {
        strcpy(tmp, zero_to_99(j / MIL));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        tenmil_hunmil(count, get, j, pr, foutp);
        return;
    }// ----------------------------------------------------------------

    else if (j / BIL == ZERO) {
        strcpy(tmp, zero_to_99(j / HUNMIL));
        if (tmp[0] == 'e')
            get = 1;
        if (tmp[0] == 'f')
            get = 2;
        if (tmp[0] == 'n')
            get = 3;
        if (tmp[0] == 'o')
            get = 4;
        if (tmp[0] == 's')
            get = 5;
        if (tmp[0] == 't')
            get = 6;
        *getit = get;
        if (getthisone != -1)
            if (get != getthisone)
                return;
        hunmil_bil(count, get, j, pr, foutp);
        return;
    }

    // -------------------------------------------------------------------------

    if (j / BIL == ONE) {
        *getit = -1;
        return;
    }// ----------------------------------------------------------------

    else {
        *getit = -1;
        return;
    }

    // -------------------------------------------------------------------------

    return;

}

// -----------------------------------------------------------------------------

// This function is the inverse of the number_word function.
//   For any integer-word zero - onebillion, word_number produces the correct
//   integer representation of the integer-word (actually a double precision
//   value).

double
word_number(char *s) {
    int words = 0, anschars = 0, done = 0, remaining = 0, n = 0;
    int k = 0, i = 0, j = 0, length = 0;
    unsigned long an[20], ans = 0LU, num[20];
    char tmp[200], type[20], answ[15][100];

    length = strlen(s);
    done = 0;
    remaining = n;
    words = 0;
    anschars = 0;
    for (i = 0; i < 15; i++)
        answ[i][0] = '\0';
    while (done < length) {
        // *********************************e***********************************
        if (s[done] == 'e') {
            done++;
            remaining--;
            if ((s[done] == 'i') && (s[done + 1] == 'g') && (s[done + 2] == 'h')
                    && (s[done + 3] == 't')) {
                done += 4;
                remaining -= 4;
                answ[words][anschars] = '8';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        anschars--;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            anschars--;
                            answ[words][anschars] = '8';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        anschars--;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        anschars--;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        anschars--;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    anschars--;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '8';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                } else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'l') && (s[done + 1] == 'e') &&
                    (s[done + 2] == 'v') && (s[done + 3] == 'e') &&
                    (s[done + 4] == 'n')) {
                done += 5;
                remaining -= 5;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                return -1.0;
            }

        }// *********************************f**********************************
        else if (s[done] == 'f') {
            done++;
            remaining--;
            if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                    (s[done + 2] == 'e')) {
                done += 3;
                remaining -= 3;
                answ[words][anschars] = '5';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'i') && (s[done + 1] == 'f') &&
                    (s[done + 2] == 't')) {
                done += 3;
                remaining -= 3;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '5';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '5';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '5';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '5';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '5';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                }
            } else if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                    (s[done + 2] == 'r')) {
                done += 3;
                remaining -= 3;
                answ[words][anschars] = '4';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else if ((s[done] == 't') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                    done += 4;
                    remaining -= 4;
                    anschars--;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '4';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                } else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'o') && (s[done + 1] == 'r') &&
                    (s[done + 2] == 't')) {
                done += 3;
                remaining -= 3;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '4';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '4';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '4';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '4';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                }
            } else {
                return -1.0;
            }
        }// *********************************n**********************************
        else if (s[done] == 'n') {
            done++;
            remaining--;
            if ((s[done] == 'i') && (s[done + 1] == 'n') && (s[done + 2] == 'e')
                    && (s[done + 3] == 't') && (s[done + 4] != 'h')) {
                done += 4;
                remaining -= 4;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '9';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '9';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                }
            } else if ((s[done] == 'i') && (s[done + 1] == 'n') &&
                    (s[done + 2] == 'e')) {
                done += 3;
                remaining -= 3;
                answ[words][anschars] = '9';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                return -1.0;
            }
        }// *********************************o**********************************
        else if (s[done] == 'o') {
            done++;
            remaining--;
            if ((s[done] == 'n') && (s[done + 1] == 'e')) {
                done += 2;
                remaining -= 2;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                return -1.0;
            }
        }// *********************************s**********************************
        else if (s[done] == 's') {
            done++;
            remaining--;
            if ((s[done] == 'i') && (s[done + 1] == 'x') && (s[done + 2] == 't')
                    && (s[done + 3] != 'h')) {
                done += 3;
                remaining -= 3;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '6';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '6';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '6';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '6';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '6';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                }
            } else if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                done += 2;
                remaining -= 2;
                answ[words][anschars] = '6';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            }
            if ((s[done] == 'e') && (s[done + 1] == 'v') && (s[done + 2] == 'e')
                    && (s[done + 3] == 'n') && (s[done + 4] == 't') &&
                    (s[done + 5] != 'h')) {
                done += 5;
                remaining -= 5;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '7';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '7';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '7';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '7';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '7';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                }
            } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                    (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                done += 4;
                remaining -= 4;
                answ[words][anschars] = '7';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                return -1.0;
            }
        }// *********************************t**********************************
        else if (s[done] == 't') {
            done++;
            remaining--;
            if ((s[done] == 'h') && (s[done + 1] == 'i') && (s[done + 2] == 'r')
                    && (s[done + 3] == 't')) {
                done += 4;
                remaining -= 4;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '3';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '3';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '3';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '3';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                } else if ((s[done] == 'e') && (s[done + 1] == 'e') &&
                        (s[done + 2] == 'n')) {
                    done += 3;
                    remaining -= 3;
                    answ[words][anschars] = '1';
                    anschars++;
                    answ[words][anschars] = '3';
                    anschars++;
                    answ[words][anschars] = '\0';
                    if (done == length)
                        continue;
                    else {
                        words++;
                        anschars = 0;
                        continue;
                    }
                }
            } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                    (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                done += 4;
                remaining -= 4;
                answ[words][anschars] = '3';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'w') && (s[done + 1] == 'e') &&
                    (s[done + 2] == 'n') && (s[done + 3] == 't')) {
                done += 4;
                remaining -= 4;
                if (s[done] == 'y') {
                    done++;
                    remaining--;
                    if ((s[done] == 'o') && (s[done + 1] == 'n') &&
                            (s[done + 2] == 'e')) {
                        done += 3;
                        remaining -= 3;
                        answ[words][anschars] = '2';
                        anschars++;
                        answ[words][anschars] = '1';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 't') && (s[done + 3] != 'u')) {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'h') && (s[done + 1] == 'r') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'e')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '3';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 'f') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'o') && (s[done + 1] == 'u') &&
                                (s[done + 2] == 'r')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '4';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'i') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e')) {
                            done += 3;
                            remaining -= 3;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '5';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if (s[done] == 's') {
                        done += 1;
                        remaining -= 1;
                        if ((s[done] == 'i') && (s[done + 1] == 'x')) {
                            done += 2;
                            remaining -= 2;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '6';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else if ((s[done] == 'e') && (s[done + 1] == 'v') &&
                                (s[done + 2] == 'e') && (s[done + 3] == 'n')) {
                            done += 4;
                            remaining -= 4;
                            answ[words][anschars] = '2';
                            anschars++;
                            answ[words][anschars] = '7';
                            anschars++;
                            answ[words][anschars] = '\0';
                            if (done == length)
                                continue;
                            else {
                                words++;
                                anschars = 0;
                                continue;
                            }
                        } else {
                            return -1.0;
                        }
                    } else if ((s[done] == 'e') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'g') && (s[done + 3] == 'h') &&
                            (s[done + 4] == 't')) {
                        done += 5;
                        remaining -= 5;
                        answ[words][anschars] = '2';
                        anschars++;
                        answ[words][anschars] = '8';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else if ((s[done] == 'n') && (s[done + 1] == 'i') &&
                            (s[done + 2] == 'n') && (s[done + 3] == 'e')) {
                        done += 4;
                        remaining -= 4;
                        answ[words][anschars] = '2';
                        anschars++;
                        answ[words][anschars] = '9';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    } else {
                        answ[words][anschars] = '2';
                        anschars++;
                        answ[words][anschars] = '0';
                        anschars++;
                        answ[words][anschars] = '\0';
                        if (done == length)
                            continue;
                        else {
                            words++;
                            anschars = 0;
                            continue;
                        }
                    }
                }
            } else if ((s[done] == 'w') && (s[done + 1] == 'o')) {
                done += 2;
                remaining -= 2;
                answ[words][anschars] = '2';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'w') && (s[done + 1] == 'e') &&
                    (s[done + 2] == 'l') && (s[done + 3] == 'v') &&
                    (s[done + 4] == 'e')) {
                done += 5;
                remaining -= 5;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '2';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'e') && (s[done + 1] == 'n')) {
                done += 2;
                remaining -= 2;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'h') && (s[done + 1] == 'o') &&
                    (s[done + 2] == 'u') && (s[done + 3] == 's') &&
                    (s[done + 4] == 'a') && (s[done + 5] == 'n') &&
                    (s[done + 6] == 'd')) {
                done += 7;
                remaining -= 7;
                answ[words][anschars] = '*';
                anschars++;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                return -1.0;
            }
        }// ********************************h*m*********************************
        else {
            if ((s[done] == 'z') && (s[done + 1] == 'e') && (s[done + 2] == 'r')
                    && (s[done + 3] == 'o'))
                return -1.0;
            else if ((s[done] == 'b') && (s[done + 1] == 'i') &&
                    (s[done + 2] == 'l') && (s[done + 3] == 'l') &&
                    (s[done + 4] == 'i') && (s[done + 5] == 'o') &&
                    (s[done + 6] == 'n'))
                return -1.0;
            else if ((s[done] == 'h') && (s[done + 1] == 'u') &&
                    (s[done + 2] == 'n') && (s[done + 3] == 'd') &&
                    (s[done + 4] == 'r') && (s[done + 5] == 'e') &&
                    (s[done + 6] == 'd')) {
                done += 7;
                remaining -= 7;
                answ[words][anschars] = '^';
                anschars++;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 't') && (s[done + 1] == 'h') &&
                    (s[done + 2] == 'o') && (s[done + 3] == 'u') &&
                    (s[done + 4] == 's') && (s[done + 5] == 'a') &&
                    (s[done + 6] == 'n') && (s[done + 7] == 'd')) {
                done += 8;
                remaining -= 8;
                answ[words][anschars] = '*';
                anschars++;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else if ((s[done] == 'm') && (s[done + 1] == 'i') &&
                    (s[done + 2] == 'l') && (s[done + 3] == 'l') &&
                    (s[done + 4] == 'i') && (s[done + 5] == 'o') &&
                    (s[done + 6] == 'n')) {
                done += 7;
                remaining -= 7;
                answ[words][anschars] = '~';
                anschars++;
                answ[words][anschars] = '1';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '0';
                anschars++;
                answ[words][anschars] = '\0';
                if (done == length)
                    continue;
                else {
                    words++;
                    anschars = 0;
                    continue;
                }
            } else {
                exit(1);
            }
        }
    }

    ////////////////////////////////////////////////////////////////////////////

    for (i = 0; i < 15; i++) {
        type[i] = '\0';
        num[i] = 0;
    }
    i = 1;
    while (i <= 15) {
        if (answ[i - 1][0] == '\0') {
            type[i] = '\0';
            break;
        } else if (answ[i - 1][0] == '*') {
            type[i] = '*';
            j = 0;
            tmp[0] = '\0';
            while (answ[i - 1][j] != '\0') {
                if (j > 0) {
                    tmp[j - 1] = answ[i - 1][j];
                }
                j++;
            }
            tmp[j - 1] = '\0';
            num[i] = atol(tmp);
            if (i <= 1)
                break;
            i++;
        } else if (answ[i - 1][0] == '^') {
            type[i] = '^';
            j = 0;
            tmp[0] = '\0';
            while (answ[i - 1][j] != '\0') {
                if (j > 0) {
                    tmp[j - 1] = answ[i - 1][j];
                }
                j++;
            }
            tmp[j - 1] = '\0';
            num[i] = atol(tmp);
            if (i <= 1)
                break;
            i++;
        } else if (answ[i - 1][0] == '~') {
            type[i] = '~';
            j = 0;
            tmp[0] = '\0';
            while (answ[i - 1][j] != '\0') {
                if (j > 0) {
                    tmp[j - 1] = answ[i - 1][j];
                }
                j++;
            }
            tmp[j - 1] = '\0';
            num[i] = atol(tmp);
            if (i <= 1)
                break;
            i++;
        } else {
            num[i] = atol(answ[i - 1]);
            if (i == 1)
                type[i] = ' ';
            else
                type[i] = '+';
            i++;
            if (answ[i - 1][0] == '\0') {
                type[i] = '\0';
                break;
            }
        }
    }
    j = i;

    i = 1;
    an[0] = an[1] = an[2] = an[3] = an[4] = an[5] = an[6] = an[7] = an[8] =
            an[9] = 0L;
    k = 1;
    an[k] = num[i];
    i++;
    while (i < j) {
        if ((type[i] == '^') && (type[i + 1] == '+') && (type[i + 2] == '+')) {
            an[k] *= num[i];
            i++;
            an[k] += num[i];
            i++;
            an[k] += num[i];
            i++;
            if (type[i] == '~') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '*') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '+') {
                k++;
                an[k] += num[i];
                i++;
                continue;
            }
            if (type[i] == '\0') {
                break;
            }
        }
        if ((type[i] == '^') && (type[i + 1] == '+')) {

            an[k] *= num[i];
            i++;
            an[k] += num[i];
            i++;
            if (type[i] == '~') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '*') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '+') {
                an[k] += num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '\0') {
                break;
            }
        }
        if ((type[i] == '^')) {
            an[k] *= num[i];
            i++;
            if (type[i] == '~') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '*') {
                an[k] *= num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '+') {
                an[k] += num[i];
                i++;
                k++;
                continue;
            }
            if (type[i] == '\0') {
                break;
            }
        }
        if ((type[i] == '~') && (type[i + 1] == '+')) {
            an[k] *= num[i];
            i++;
            k++;
            continue;
        }
        if ((type[i] == '*') && (type[i + 1] == '+')) {
            an[k] *= num[i];
            i++;
            k++;
            continue;
        }
        if ((type[i] == '~') && (type[i + 1] == '\0')) {
            an[k] *= num[i];
            break;
        }
        if ((type[i] == '*') && (type[i + 1] == '\0')) {
            an[k] *= num[i];
            break;
        }
        if ((type[i] == '^') && (type[i + 1] == '\0')) {
            an[k] *= num[i];
            break;
        }
        if ((type[i] == '+') && (type[i + 1] == '\0')) {
            an[k] += num[i];
            break;
        }
        if ((type[i] == '*')) {
            an[k] *= num[i];
            i++;
        }
        if ((type[i] == '+')) {
            an[k] += num[i];
            i++;
        }
        if ((type[i] == '\0')) {
            break;
        }
    }

    ans = an[0] + an[1] + an[2] + an[3] + an[4] + an[5] + an[6] + an[7] + an[8]
            + an[9];
    return ( (double) ans);
}

// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
// ------------------------------EOF--------------------------------------------
